Index: src/mips/full-codegen-mips.cc |
diff --git a/src/mips/full-codegen-mips.cc b/src/mips/full-codegen-mips.cc |
index b085859d00bd2a6194d210ad7d749ff69cdd10ad..c1472bb4eb0c0f78a376d67b94efd37e0d2c99f3 100644 |
--- a/src/mips/full-codegen-mips.cc |
+++ b/src/mips/full-codegen-mips.cc |
@@ -918,7 +918,7 @@ void FullCodeGenerator::VisitForInStatement(ForInStatement* stmt) { |
Label convert, done_convert; |
__ JumpIfSmi(a0, &convert); |
__ GetObjectType(a0, a1, a1); |
- __ Branch(&done_convert, hs, a1, Operand(FIRST_JS_OBJECT_TYPE)); |
+ __ Branch(&done_convert, ge, a1, Operand(FIRST_SPEC_OBJECT_TYPE)); |
__ bind(&convert); |
__ push(a0); |
__ InvokeBuiltin(Builtins::TO_OBJECT, CALL_FUNCTION); |
@@ -2477,9 +2477,9 @@ void FullCodeGenerator::EmitIsObject(ZoneList<Expression*>* args) { |
__ And(at, a1, Operand(1 << Map::kIsUndetectable)); |
__ Branch(if_false, ne, at, Operand(zero_reg)); |
__ lbu(a1, FieldMemOperand(a2, Map::kInstanceTypeOffset)); |
- __ Branch(if_false, lt, a1, Operand(FIRST_JS_OBJECT_TYPE)); |
+ __ Branch(if_false, lt, a1, Operand(FIRST_NONCALLABLE_SPEC_OBJECT_TYPE)); |
PrepareForBailoutBeforeSplit(TOS_REG, true, if_true, if_false); |
- Split(le, a1, Operand(LAST_JS_OBJECT_TYPE), if_true, if_false, fall_through); |
+ Split(le, a1, Operand(LAST_NONCALLABLE_SPEC_OBJECT_TYPE), if_true, if_false, fall_through); |
Mads Ager (chromium)
2011/06/06 08:44:20
Line too long.
|
context()->Plug(if_true, if_false); |
} |
@@ -2500,7 +2500,7 @@ void FullCodeGenerator::EmitIsSpecObject(ZoneList<Expression*>* args) { |
__ JumpIfSmi(v0, if_false); |
__ GetObjectType(v0, a1, a1); |
PrepareForBailoutBeforeSplit(TOS_REG, true, if_true, if_false); |
- Split(ge, a1, Operand(FIRST_JS_OBJECT_TYPE), |
+ Split(ge, a1, Operand(FIRST_SPEC_OBJECT_TYPE), |
if_true, if_false, fall_through); |
context()->Plug(if_true, if_false); |
@@ -2779,14 +2779,15 @@ void FullCodeGenerator::EmitClassOf(ZoneList<Expression*>* args) { |
// Check that the object is a JS object but take special care of JS |
// functions to make sure they have 'Function' as their class. |
__ GetObjectType(v0, v0, a1); // Map is now in v0. |
- __ Branch(&null, lt, a1, Operand(FIRST_JS_OBJECT_TYPE)); |
+ __ Branch(&null, lt, a1, Operand(FIRST_SPEC_OBJECT_TYPE)); |
- // As long as JS_FUNCTION_TYPE is the last instance type and it is |
- // right after LAST_JS_OBJECT_TYPE, we can avoid checking for |
- // LAST_JS_OBJECT_TYPE. |
- ASSERT(LAST_TYPE == JS_FUNCTION_TYPE); |
- ASSERT(JS_FUNCTION_TYPE == LAST_JS_OBJECT_TYPE + 1); |
- __ Branch(&function, eq, a1, Operand(JS_FUNCTION_TYPE)); |
+ // As long as LAST_CALLABLE_SPEC_OBJECT_TYPE is the last instance type, and |
+ // FIRST_CALLABLE_SPEC_OBJECT_TYPE comes right after |
+ // LAST_NONCALLABLE_SPEC_OBJECT_TYPE, we can avoid checking for the latter. |
+ STATIC_ASSERT(LAST_TYPE == LAST_CALLABLE_SPEC_OBJECT_TYPE); |
+ STATIC_ASSERT(FIRST_CALLABLE_SPEC_OBJECT_TYPE == |
+ LAST_NONCALLABLE_SPEC_OBJECT_TYPE + 1); |
+ __ Branch(&function, ge, a1, Operand(FIRST_CALLABLE_SPEC_OBJECT_TYPE)); |
// Check if the constructor in the map is a function. |
__ lw(v0, FieldMemOperand(v0, Map::kConstructorOffset)); |
@@ -4098,7 +4099,7 @@ bool FullCodeGenerator::TryLiteralCompare(Token::Value op, |
} else if (check->Equals(isolate()->heap()->function_symbol())) { |
__ JumpIfSmi(v0, if_false); |
__ GetObjectType(v0, a1, v0); // Leave map in a1. |
- Split(ge, v0, Operand(FIRST_FUNCTION_CLASS_TYPE), |
+ Split(ge, v0, Operand(FIRST_CALLABLE_SPEC_OBJECT_TYPE), |
if_true, if_false, fall_through); |
} else if (check->Equals(isolate()->heap()->object_symbol())) { |
@@ -4107,9 +4108,9 @@ bool FullCodeGenerator::TryLiteralCompare(Token::Value op, |
__ Branch(if_true, eq, v0, Operand(at)); |
// Check for JS objects => true. |
__ GetObjectType(v0, v0, a1); |
- __ Branch(if_false, lo, a1, Operand(FIRST_JS_OBJECT_TYPE)); |
+ __ Branch(if_false, lt, a1, Operand(FIRST_NONCALLABLE_SPEC_OBJECT_TYPE)); |
__ lbu(a1, FieldMemOperand(v0, Map::kInstanceTypeOffset)); |
- __ Branch(if_false, hs, a1, Operand(FIRST_FUNCTION_CLASS_TYPE)); |
+ __ Branch(if_false, gt, a1, Operand(LAST_NONCALLABLE_SPEC_OBJECT_TYPE)); |
// Check for undetectable objects => false. |
__ lbu(a1, FieldMemOperand(v0, Map::kBitFieldOffset)); |
__ And(a1, a1, Operand(1 << Map::kIsUndetectable)); |